@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Cookies API for Server & Client - ~/lib/Cookie.pm
-## Version v0.1.4
+## Version v0.1.5
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/10/08
-## Modified 2021/11/22
+## Modified 2021/11/25
 ## You can use, copy, modify and  redistribute  this  package  and  associated
 ## files under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
@@ -27,9 +27,10 @@ BEGIN
         '=='     => \&same_as,
         fallback => 1,
     );
-    our $VERSION = 'v0.1.4';
+    our $VERSION = 'v0.1.5';
     our $SUBS;
     our $COOKIE_DEBUG = 0;
+    use constant CRYPTX_VERSION => '0.074';
 };
 
 sub init
@@ -92,7 +93,7 @@ sub algo
         {
             try
             {
-                $self->_load_class( 'Crypt::Mode::CBC' ) || return( $self->pass_error );
+                $self->_load_class( 'Crypt::Mode::CBC', { version => CRYPTX_VERSION } ) || return( $self->pass_error );
                 # Crypt::Mode::CBC dies when it is unhappy, but we catch a null return 
                 # value anyway just in case
                 my $o = Crypt::Mode::CBC->new( $algo ) ||
@@ -188,14 +189,14 @@ sub as_string
         {
             if( $self->sign->is_true )
             {
-                $self->_load_class( 'Crypt::Mac::HMAC' ) || return( $self->pass_error );
+                $self->_load_class( 'Crypt::Mac::HMAC', { version => CRYPTX_VERSION } ) || return( $self->pass_error );
                 my $signature = Crypt::Mac::HMAC::hmac_b64( "SHA256", "$key", "$value" );
                 $value = "$value.$signature";
                 $self->message( 4, "Signature is '$signature' with new cookie value '$value'" );
             }
             elsif( $self->encrypt )
             {
-                $self->_load_class( 'Crypt::Misc' ) || return( $self->pass_error );
+                $self->_load_class( 'Crypt::Misc', { version => CRYPTX_VERSION } ) || return( $self->pass_error );
                 my $algo = $self->algo;
                 my $p = $self->_encrypt_objects( $key => $algo ) || return( $self->pass_error );
                 my $crypt = $p->{crypt};
@@ -282,7 +283,7 @@ sub decrypt
     # $self->message( 4, "Value to decrypt is '$value'" );
     try
     {
-        $self->_load_class( 'Crypt::Misc' ) || return( $self->pass_error );
+        $self->_load_class( 'Crypt::Misc', { version => CRYPTX_VERSION } ) || return( $self->pass_error );
         # If IV is not provided, _encrypt_objects will generate one and save it for next time
         my $p = $self->_encrypt_objects( $key => $algo, $opts->{iv} ) || return( $self->pass_error );
         my $crypt = $p->{crypt};
@@ -474,7 +475,7 @@ sub is_valid
     $self->message( 3, "Original string is '$orig' and signature is '$sig' and key is '$key'." );
     try
     {
-        $self->_load_class( 'Crypt::Mac::HMAC' ) || return( $self->pass_error );
+        $self->_load_class( 'Crypt::Mac::HMAC', { version => CRYPTX_VERSION } ) || return( $self->pass_error );
         my $check = Crypt::Mac::HMAC::hmac_b64( 'SHA256', "$key", "$orig" );
         # $self->message( 3, "Is check '$check' same as signature '$sig' ? ", ( $check eq $sig ? 'yes' : 'no' ) );
         return( "$check" eq "$sig" );
@@ -664,7 +665,7 @@ sub _encrypt_objects
     $iv //= '';
     try
     {
-        $self->_load_class( 'Crypt::Mode::CBC' ) || return( $self->pass_error );
+        $self->_load_class( 'Crypt::Mode::CBC', { version => CRYPTX_VERSION } ) || return( $self->pass_error );
         $self->_load_class( 'Bytes::Random::Secure' ) || return( $self->pass_error );
         # $self->message( 4, "Algorithm is '$algo'" );
         my $crypt = Crypt::Mode::CBC->new( "$algo" ) || return( $self->error( "Unable to create a Crypt::Mode::CBC object." ) );
@@ -835,7 +836,7 @@ Cookie - Cookie Object with Encryption or Signature
 
 =head1 VERSION
 
-    v0.1.4
+    v0.1.5
 
 =head1 DESCRIPTION
 
@@ -1386,6 +1387,41 @@ The methods available to use for cookie encryption are: L</algo> to set the desi
 
 Cookie encryption is performed by L<CryptX>, which is an XS module, and thus very fast.
 
+=head1 INSTALLATION
+
+As usual, to install this module, you can do:
+
+    perl Makefile.PL
+    make
+    make test
+    sudo make install
+
+If you have Apache/modperl2 installed, this will also prepare the Makefile and run test under modperl.
+
+The Makefile.PL tries hard to find your Apache configuration, but you can give it a hand by specifying some command line parameters. See L<Apache::TestMM> for available parameters or you can type on the command line:
+
+    perl -MApache::TestConfig -le 'Apache::TestConfig::usage()'
+
+For example:
+
+    perl Makefile.PL -apxs /usr/bin/apxs -port 1234
+    # which will also set the path to httpd_conf, otherwise
+    perl Makefile.PL -httpd_conf /etc/apache2/apache2.conf
+
+    # then
+    make
+    make test
+    sudo make install
+
+See also L<modperl testing documentation|https://perl.apache.org/docs/general/testing/testing.html>
+
+But, if for some reason, you do not want to perform the mod_perl tests, you can call use C<NO_MOD_PERL=1> when calling C<perl Makefile.PL>, such as:
+
+    NO_MOD_PERL=1 perl Makefile.PL
+    make
+    make test
+    sudo make install
+
 =head1 AUTHOR
 
 Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
